@@ -2,9 +2,7 @@
 from dataclasses import dataclass, field
 from typing import Iterator, List, Optional
 
-import mkapi.core.preprocess
-from mkapi.core import linker
-from mkapi.core.preprocess import strip_ptags
+from mkapi.core import linker, preprocess
 from mkapi.core.regex import LINK_PATTERN
 from mkapi.core.signature import Signature
 
@@ -35,13 +33,11 @@ class Base:
 
 
 @dataclass
-class Type(Base):
-    """Type class represents type for [Item](), [Section](), [Docstring](),
-    and [Object]()."""
+class Inline(Base):
+    """Inline class."""
 
     def __post_init__(self):
-        if not self.markdown:
-            self.markdown = self.name
+        self.markdown = self.name
 
     def __bool__(self) -> bool:
         """Returns True if name is not empty."""
@@ -49,34 +45,71 @@ class Type(Base):
 
     def __iter__(self) -> Iterator[Base]:
         """Yields self if the markdown attribute has link form."""
-        if LINK_PATTERN.search(self.markdown):
+        if self.markdown:
             yield self
 
     def set_html(self, html: str):
         """Sets `html` attribute cleaning `p` tags."""
-        self.html = strip_ptags(html)
+        self.html = preprocess.strip_ptags(html)
 
 
 @dataclass
-class Item(Base):
+class Type(Inline):
+    """Type class represents type for [Item](), [Section](), [Docstring](),
+    and [Object]().
+
+    Examples:
+        >>> Type('a')
+        Type(name='a', markdown='', html='a')
+        >>> Type('[a](b)')
+        Type(name='[a](b)', markdown='[a](b)', html='')
+    """
+
+    def __post_init__(self):
+        if LINK_PATTERN.search(self.name):
+            self.markdown = self.name
+        else:
+            self.html = self.name
+
+
+@dataclass
+class Item(Type):
     """Item class represents an item in Parameters, Attributes, and Raises sections.
 
     Args:
         type: Type of self.
+        kind: Kind of item, for example `readonly_property`. This value is rendered
+            to CSS class attribute.
 
     Attributes:
         type: Type of self.
+        kind: Kind of item, for example `readonly_property`. This value is rendered
+            to CSS class attribute.
+
+    Examples:
+        >>> item = Item('a', 'abc')
+        >>> item.name, item.markdown, item.html
+        ('a', '', 'a')
     """
 
     type: Type = field(default_factory=Type)
+    desc: Inline = field(init=False)
+    kind: str = ""
+
+    def __post_init__(self):
+        self.desc = Inline(self.markdown)
+        self.markdown = ""
+        super().__post_init__()
 
     def __iter__(self) -> Iterator[Base]:
+        if self.markdown:
+            yield self
         yield from self.type
-        yield self
+        yield from self.desc
 
     def set_html(self, html: str):
-        """Sets `html` attribute cleaning `p` tags."""
-        self.html = strip_ptags(html)
+        html = html.replace("<strong>", "__").replace("</strong>", "__")
+        super().set_html(html)
 
 
 @dataclass
@@ -97,13 +130,13 @@ class Section(Base):
         >>> for x in section:
         ...     assert x is section
 
-        >>> items = [Item('x'), Item('y'), Item('z')]
+        >>> items = [Item('x'), Item('[y](a)'), Item('z')]
         >>> section = Section('Parameters', items=items)
         >>> [item.name for item in section]
-        ['x', 'y', 'z']
+        ['[y](a)']
 
         Indexing:
-        >>> isinstance(section['y'], Item)
+        >>> isinstance(section['x'], Item)
         True
         >>> section['z'].name
         'z'
@@ -118,7 +151,7 @@ class Section(Base):
 
     def __post_init__(self):
         if self.markdown:
-            self.markdown = mkapi.core.preprocess.convert(self.markdown)
+            self.markdown = preprocess.convert(self.markdown)
 
     def __iter__(self) -> Iterator[Base]:
         """Yields [Base]() instance that has non empty Markdown.
@@ -163,6 +196,9 @@ class Section(Base):
         return self[name] is not None
 
 
+SECTION_ORDER = ["Bases", "", "Parameters", "Attributes", "Returns", "Yields", "Raises"]
+
+
 @dataclass
 class Docstring:
     """Docstring class represents a docstring of an object.
@@ -182,13 +218,13 @@ class Docstring:
 
         Docstring with 3 sections:
         >>> default = Section("", markdown="Default")
-        >>> parameters = Section("Parameters", items=[Item("a"), Item("b")])
+        >>> parameters = Section("Parameters", items=[Item("a"), Item("[b](!a)")])
         >>> returns = Section("Returns", markdown="Results")
         >>> docstring = Docstring([default, parameters, returns])
 
         `Docstring` is iterable:
         >>> [base.name for base in docstring]
-        ['', 'a', 'b', 'Returns']
+        ['', '[b](!a)', 'Returns']
 
         Indexing:
         >>> docstring["Parameters"].items[0].name
@@ -217,13 +253,16 @@ class Docstring:
             if section_.name == name:
                 self.sections[k] = section
                 return
-            if name == "Bases":
+        if name not in SECTION_ORDER:
+            self.sections.append(section)
+            return
+        order = SECTION_ORDER.index(name)
+        for k, section_ in enumerate(self.sections):
+            if section_.name not in SECTION_ORDER:
                 self.sections.insert(k, section)
                 return
-            if name == "Parameters" and section_.name not in ["", "Bases"]:
-                self.sections.insert(k, section)
-                return
-            if section_.name in ["Raises", "Yields", "Returns"]:
+            order_ = SECTION_ORDER.index(section_.name)
+            if order < order_:
                 self.sections.insert(k, section)
                 return
         self.sections.append(section)
